---
title: Overview
page_title: Overview | Kendo UI DateInput HtmlHelper
description: "Get started with the server-side wrapper for the Kendo UI DateInput widget for ASP.NET MVC."
slug: overview_dateinputhelper_aspnetmvc
position: 1
---

# DateInput HtmlHelper Overview

The DateInput HtmlHelper extension is a server-side wrapper for the [Kendo UI DateInput](https://demos.telerik.com/kendo-ui/dateinput/index) widget.

## Configuration

Below are listed the steps for you to follow when configuring the Kendo UI DateInput.

1. Make sure you followed all the steps from the [introductory article on Telerik UI for ASP.NET MVC]({% slug overview_aspnetmvc %}).

1. Create a new action method which renders the view.

    ###### Example

            public ActionResult Index()
            {
                return View();
            }

1. Add a DateInput.

    ###### Example

    ```tab-ASPX

            <%: Html.Kendo().DateInput()
                .Name("dateinput") //The name of the DateInput is mandatory. It specifies the "id" attribute of the widget.
                .Value(DateTime.Today) //Set the value of the DateInput.
            %>
    ```
    ```tab-Razor

            @(Html.Kendo().DateInput()
                .Name("dateinput") //The name of the DateInput is mandatory. It specifies the "id" attribute of the widget.
                .Value(DateTime.Today) //Set the value of the DateInput.
            )
    ```

## Event Handling

You can subscribe to all DateInput [events](../../../kendo-ui/api/javascript/ui/dateinput#events).

### By Handler Name

The following example demonstrates how to subscribe to events by a handler name.

###### Example

```tab-ASPX

        <%: Html.Kendo().DateInput()
            .Name("dateinput")
            .Events(e => e
                .Change("dateInput_change")
            )
        %>
        <script>
        function dateInput_change() {
            //Handle the change event
        }
        </script>
```
```tab-Razor

        @(Html.Kendo().DateInput()
          .Name("dateinput")
          .Events(e => e
                .Change("dateInput_change")
          )
        )
        <script>
        function dateInput_change() {
            //Handle the change event
        }
        </script>
```

### By Template Delegate

The following example demonstrates how to subscribe to events by a template delegate.

###### Example

```tab-Razor

    @(Html.Kendo().DateInput()
      .Name("dateinput")
      .Events(e => e
          .Change(@<text>
            function() {
                //Handle the change event inline.
            }
            </text>)
      )
    )
```

## Reference

### Existing Instances

To reference an existing Kendo UI DateInput instance, use the [`jQuery.data()`](http://api.jquery.com/jQuery.data/) configuration option. Once a reference is established, use the [DateInput API](../../../kendo-ui/api/javascript/ui/dateinput#methods) to control its behavior.

###### Example

        //Put this after your Kendo UI DateInput for ASP.NET MVC declaration.
        <script>
        $(function() {
        //Notice that the Name() of the DateInput is used to get its client-side instance.
        var dateInput = $("#dateinput").data("kendoDateInput");
        });
        </script>

## See Also

* [ASP.NET MVC API Reference: DateInputBuilder](../../../kendo-ui/api/Kendo.Mvc.UI.Fluent/DateInputBuilder)
* [Overview of Telerik UI for ASP.NET MVC]({% slug overview_aspnetmvc %})
* [Fundamentals of Telerik UI for ASP.NET MVC]({% slug fundamentals_aspnetmvc %})
* [Scaffolding in Telerik UI for ASP.NET MVC]({% slug scaffolding_aspnetmvc %})
* [Overview of the Kendo UI DatePicker Widget](../../../kendo-ui/controls/editors/datepicker/overview)
* [Telerik UI for ASP.NET MVC API Reference Folder](../../../kendo-ui/api/Kendo.Mvc/AggregateFunction)
* [Telerik UI for ASP.NET MVC HtmlHelpers Folder]({% slug overview_autocompletehelper_aspnetmvc %})
* [Tutorials on Telerik UI for ASP.NET MVC]({% slug overview_timeefficiencyapp_aspnetmvc6 %})
* [Telerik UI for ASP.NET MVC Troubleshooting]({% slug troubleshooting_aspnetmvc %})
